part of 'customer_exercise_device_bloc.dart';

abstract class CustomerExerciseDeviceState extends Equatable {
  const CustomerExerciseDeviceState();

  @override
  List<Object> get props => [];
}

class CustomerExerciseDeviceInitial extends CustomerExerciseDeviceState {
  const CustomerExerciseDeviceInitial();
}

class CustomerExerciseDeviceLoading extends CustomerExerciseDeviceState {
  const CustomerExerciseDeviceLoading();
}

class CustomerExerciseDeviceReady extends CustomerExerciseDeviceState {
  const CustomerExerciseDeviceReady();
}

class CustomerExerciseDeviceError extends CustomerExerciseDeviceState {
  final String message;
  const CustomerExerciseDeviceError({required this.message});

  @override
  List<Object> get props => [message];
}
